@@ -3,6 +3,7 @@ import unittest
 
 import numpy as np
 import tests.helper as helper
+import thingsvision.core.extraction.extractor
 
 Array = np.ndarray
 
@@ -12,7 +13,7 @@ class ExtractionPretrainedTestCase(unittest.TestCase):
     def setUpClass(cls):
         helper.create_test_images()
 
-    def test_extraction_pretrained_modells(self):
+    def test_extraction_pretrained_models(self):
         """Tests basic feature extraction pipeline."""
         for (
             extractor,
@@ -30,7 +31,6 @@ class ExtractionPretrainedTestCase(unittest.TestCase):
                     batches=batches,
                     module_name=module_name,
                     flatten_acts=False,
-                    clip=clip,
                 )
 
                 self.assertTrue(isinstance(features, Array))
@@ -47,7 +47,6 @@ class ExtractionPretrainedTestCase(unittest.TestCase):
                         batches=batches,
                         module_name=module_name,
                         flatten_acts=False,
-                        clip=clip,
                     )
 
                     self.assertTrue(isinstance(features, Array))
